package com.bonus.canteen.core.supermarket.service;

import java.util.List;
import com.bonus.canteen.core.supermarket.domain.SupermarketMaterialType;

/**
 * 商品类别Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface ISupermarketMaterialTypeService {
    /**
     * 查询商品类别
     * 
     * @param materialTypeId 商品类别主键
     * @return 商品类别
     */
    public SupermarketMaterialType selectSupermarketMaterialTypeByMaterialTypeId(Long materialTypeId);

    /**
     * 查询商品类别列表
     * 
     * @param supermarketMaterialType 商品类别
     * @return 商品类别集合
     */
    public List<SupermarketMaterialType> selectSupermarketMaterialTypeList(SupermarketMaterialType supermarketMaterialType);

    /**
     * 新增商品类别
     * 
     * @param supermarketMaterialType 商品类别
     * @return 结果
     */
    public int insertSupermarketMaterialType(SupermarketMaterialType supermarketMaterialType);

    /**
     * 修改商品类别
     * 
     * @param supermarketMaterialType 商品类别
     * @return 结果
     */
    public int updateSupermarketMaterialType(SupermarketMaterialType supermarketMaterialType);

    /**
     * 批量删除商品类别
     * 
     * @param materialTypeIds 需要删除的商品类别主键集合
     * @return 结果
     */
    public int deleteSupermarketMaterialTypeByMaterialTypeIds(Long[] materialTypeIds);

    /**
     * 删除商品类别信息
     * 
     * @param materialTypeId 商品类别主键
     * @return 结果
     */
    public int deleteSupermarketMaterialTypeByMaterialTypeId(Long materialTypeId);
}
