package com.bonus.canteen.core.supermarket.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supermarket.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supermarket.domain.SupermarketMaterialType;
import com.bonus.canteen.core.supermarket.service.ISupermarketMaterialTypeService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 商品类别Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "商品类别接口")
@RestController
@RequestMapping("/supermarket_material_type")
public class SupermarketMaterialTypeController extends BaseController {
    @Autowired
    private ISupermarketMaterialTypeService supermarketMaterialTypeService;

    /**
     * 查询商品类别列表
     */
    @ApiOperation(value = "查询商品类别列表")
    //@RequiresPermissions("supermarket:type:list")
    @GetMapping("/list")
    public TableDataInfo list(SupermarketMaterialType supermarketMaterialType) {
        startPage();
        List<SupermarketMaterialType> list = supermarketMaterialTypeService.selectSupermarketMaterialTypeList(supermarketMaterialType);
        return getDataTable(list);
    }

    /**
     * 导出商品类别列表
     */
    @ApiOperation(value = "导出商品类别列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:type:export")
    @SysLog(title = "商品类别", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出商品类别")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupermarketMaterialType supermarketMaterialType) {
        List<SupermarketMaterialType> list = supermarketMaterialTypeService.selectSupermarketMaterialTypeList(supermarketMaterialType);
        ExcelUtil<SupermarketMaterialType> util = new ExcelUtil<SupermarketMaterialType>(SupermarketMaterialType.class);
        util.exportExcel(response, list, "商品类别数据");
    }

    /**
     * 获取商品类别详细信息
     */
    @ApiOperation(value = "获取商品类别详细信息")
    //@RequiresPermissions("supermarket:type:query")
    @GetMapping(value = "/{materialTypeId}")
    public AjaxResult getInfo(@PathVariable("materialTypeId") Long materialTypeId) {
        return success(supermarketMaterialTypeService.selectSupermarketMaterialTypeByMaterialTypeId(materialTypeId));
    }

    /**
     * 新增商品类别
     */
    @ApiOperation(value = "新增商品类别")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:type:add")
    @SysLog(title = "商品类别", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增商品类别")
    @PostMapping
    public AjaxResult add(@RequestBody SupermarketMaterialType supermarketMaterialType) {
        try {
            return toAjax(supermarketMaterialTypeService.insertSupermarketMaterialType(supermarketMaterialType));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改商品类别
     */
    @ApiOperation(value = "修改商品类别")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:type:edit")
    @SysLog(title = "商品类别", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改商品类别")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupermarketMaterialType supermarketMaterialType) {
        try {
            return toAjax(supermarketMaterialTypeService.updateSupermarketMaterialType(supermarketMaterialType));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除商品类别
     */
    @ApiOperation(value = "删除商品类别")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:type:remove")
    @SysLog(title = "商品类别", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除商品类别")
	@PostMapping("/del/{materialTypeIds}")
    public AjaxResult remove(@PathVariable Long[] materialTypeIds) {
        return toAjax(supermarketMaterialTypeService.deleteSupermarketMaterialTypeByMaterialTypeIds(materialTypeIds));
    }
}
